@@ -1,3 +1,8 @@
+{% macro replace_quotes(input_string) %}
+  {{ return(input_string.replace("'","''")) }}
+{% endmacro %}
+
+
 {% macro exasol__basic_load_csv_rows(model, batch_size, agate_table) %}
     {% set cols_sql = get_seed_column_quoted_csv(model, agate_table.column_names) %}
     {% set bindings = [] %}
@@ -6,22 +11,21 @@
 
     {% for chunk in agate_table.rows | batch(batch_size) %}
         {% set bindings = [] %}
-        {{log(chunk)}}
         {% for row in chunk %}
           {% do bindings.extend(row) %}
-          {{log(row)}}
         {% endfor %}
-        {{log(bindings)}}
-        {{log(agate_table.column_names)}}
 
         {% set sql %}
             insert into {{ this.render() }} ({{ cols_sql }}) values
             {% for row in chunk -%}
                 ({%- for column in agate_table.column_names -%}
-                    {{"'" ~ row[column] ~"'"}}
+                    {% set col_type = agate_table.columns[column].data_type | string %}
+                    {%- if "text.Text" in col_type -%}
+                      '{{replace_quotes(row[column]) if row[column]}}' {% else %} '{{ row[column] if row[column] }}'
+                    {%- endif -%}
                     {%- if not loop.last%},{%- endif %}
                 {%- endfor -%})
-                {%- if not loop.last%},{%- endif %}
+                {%- if not loop.last%}{{','+'\n'}}{%- endif %}
             {%- endfor %}
         {% endset %}
 
